--IF RUNNING THIS SCRIPT IN SQL MGMT STUDIO
--1. FROM QUERY MENU, SELECT SQLCMD Mode
--2. UNCOMMENT LINE BELOW AND REPLACE "EN" WITH APPROPRIATE LANGUAGE CODE 
--:setvar languagecode "EN"

-------------------------------------------------------------------------------
-- SQL Server - SSRECV_XDL Grid
-------------------------------------------------------------------------------
BEGIN TRAN T1

declare
	@v_grid_name VARCHAR(40),
	@v_grid_id NUMERIC(14),
	@v_field_id NUMERIC(14),
	@v_field_id_list VARCHAR(1000),
	@v_grid_key_fields VARCHAR(200),
	@v_dataspy_id NUMERIC(14),
	@sChk varchar(3);

-------------------------------------------------------------------------------
-- Set custom grid name
-------------------------------------------------------------------------------

SET @v_grid_name = 'SSRECV_XDL';

-------------------------------------------------------------------------------
-- Cleanup existing r5boilertexts
-------------------------------------------------------------------------------

IF EXISTS (select BOT_FUNCTION
from r5boilertexts
where (BOT_FUNCTION = 'SSRECV' and BOT_NUMBER > 5000 AND bot_lang = '$(languagecode)'))
BEGIN
	DELETE FROM r5boilertexts where (BOT_FUNCTION = 'SSRECV' AND BOT_NUMBER > 5000 AND bot_lang = '$(languagecode)');
END

-------------------------------------------------------------------------------
-- Cleanup existing r5grid and related data
-------------------------------------------------------------------------------

IF EXISTS (select grd_gridid from r5grid where GRD_GRIDNAME = @v_grid_name)
BEGIN
	DELETE FROM r5queryfield where DQF_DDSPYID in
    (
        select DDS_DDSPYID from R5dddataspy where DDS_GRIDID in
        (
            select grd_gridid from r5grid where GRD_GRIDNAME = @v_grid_name
        )
    );
	DELETE FROM R5USEGRIDSYSDEFAULT where USD_DATASPYID in 
    (
        select DDS_DDSPYID from R5dddataspy where DDS_GRIDID in
        (
            select grd_gridid from r5grid where GRD_GRIDNAME = @v_grid_name
        )
    );
    DELETE FROM R5dddataspy WHERE DDS_GRIDID in
    (
        select grd_gridid from r5grid where GRD_GRIDNAME = @v_grid_name
    );
    DELETE FROM r5gridfield where GFD_GRIDID in
    (
        select grd_gridid from r5grid where GRD_GRIDNAME = @v_grid_name
    );
	DELETE FROM r5gridparam WHERE GDP_GRIDID in
    (
        select grd_gridid from r5grid where GRD_GRIDNAME = @v_grid_name
    );
    DELETE FROM r5grid WHERE GRD_GRIDNAME = @v_grid_name;
END


-------------------------------------------------------------------------------
-- Cleanup existing r5functions
-------------------------------------------------------------------------------
--********************DO NOT CLEANUP FUNCTION SSRECV***************************

-------------------------------------------------------------------------------
--Insert r5functions
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- Insert r5grid
-------------------------------------------------------------------------------

-- select @v_grid_id = MAX(grd_gridid)+1 from r5grid;
EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_grid_id OUTPUT, 'GRD', '1', @sChk OUTPUT;
PRINT 'Grid Id: ' + str(@v_grid_id)

insert into r5grid
(
    GRD_GRIDID,
    GRD_DESC,
    GRD_BASEQUERY,
    GRD_GRIDNAME,
    GRD_BOTFUNCTION,
    GRD_PORTLETFLAG,
    GRD_SECENTITY,
    GRD_HINTS,
    GRD_TAB,
    GRD_GRIDTYPE,
    GRD_UNITS,
    GRD_OPTIMIZERON,
    GRD_DISTINCT,
    GRD_COMMITFLAG,
    GRD_CUSTOMFIELDCODE,
    GRD_NOSCREENDESIGNER
)
values
(
    @v_grid_id,
    'PO Receipt Active Lines (AM)',
    'FROM r5docklines d
    inner join r5dockreceipts r on (
        d.DKL_DCKCODE = r.DCK_CODE
    )
    left outer join R5ORDERLINES o on (
    	d.DKL_ORDER = o.ORL_ORDER and
    	d.DKL_ORDLINE = o.ORL_ORDLINE and
    	d.DKL_ORDER_ORG = o.ORL_ORDER_ORG
    )
    inner join R5PARTS p on (
    	d.DKL_PART = p.PAR_CODE and
    	d.DKL_PART_ORG = p.PAR_ORG
    )
    left outer join R5EVENTS e on (
        o.ORL_EVENT = e.EVT_CODE
    )
    WHERE d.dkl_dckcode = :param.poreceiptcode
    AND d.dkl_linerstatus IN (''U'', ''R'', ''C'')',
    @v_grid_name,
    'SSRECV',
    '-',
    NULL,
    NULL,
    '+',
    2,
    NULL,
    '-',
    '-',
    NULL,
    NULL,
    '-'
);

-------------------------------------------------------------------------------
-- Insert r5dddataspy
-------------------------------------------------------------------------------

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_dataspy_id OUTPUT, 'DDS', '1', @sChk OUTPUT;
PRINT 'Dataspy Id: ' + str(@v_dataspy_id)

insert into R5dddataspy
(
    DDS_DDSPYNAME,
    DDS_DDSPYID,
    DDS_AUTORUN,
    DDS_SCOPE,
    DDS_ORGANIZATION,
    DDS_UPDATESTAMP,
    DDS_UPDATEBYUSER,
    DDS_CREATEDSTAMP,
    DDS_UPDATEABLE,
    DDS_FILTERSTRXML,
    DDS_SORTSTRXML,
    DDS_FIELDLIST,
    DDS_DISPLAYROW,
    DDS_OWNER,
    DDS_GRIDID,
    DDS_TYPE,
    DDS_DEFAULTFLAG,
    DDS_FIELDLIST_PORTLET,
    DDS_CLIENTROWS,
    DDS_PORTLETROWS,
    DDS_HINTS,
    DDS_BOTNAME,
    DDS_USERFILTER,
    DDS_SECURITYDATASPY,
    DDS_MEKEY
)
values
(
    'All Records - AM',
    @v_dataspy_id,
    NULL,
    '-',
    '*',
    NULL,
    NULL,
    getdate(),
    '-',
    '<FILTERABLE />',
    '<SORTABLE />',
    NULL,
    NULL,
    'R5',
    @v_grid_id,
    'SD',
    '+',
    NULL,
    30,
    NULL,
    NULL,
    'DSNAME_XDL',
    NULL,
    '-',
    'YY'
);


-------------------------------------------------------------------------------
-- Insert into r5GridParams
-------------------------------------------------------------------------------
insert into r5gridparam (GDP_GRIDID, GDP_PARAM, GDP_TAGNAME, GDP_DATATYPE, GDP_UPDATECOUNT)
values (@v_grid_id, 'param.poreceiptcode', 'RECEIPTCODE', 'String', 1);

insert into r5gridparam (GDP_GRIDID, GDP_PARAM, GDP_TAGNAME, GDP_DATATYPE, GDP_UPDATECOUNT)
values (@v_grid_id, 'parameter.language', NULL, NULL, 0);


-------------------------------------------------------------------------------
-- Insert r5boilertexts
-------------------------------------------------------------------------------

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5001, 255, 0, 0, '$(languagecode)', 'PO Receipt Active Lines (AM)', 'TB', '1', 'XDL', NULL, NULL, NULL, NULL, '0', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5002, 100, 0, 0, '$(languagecode)', 'All Records', 'F', '1', 'XDL_DSNAME', NULL, NULL, NULL, NULL, '10000', NULL, NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5003, 100, 0, 0, '$(languagecode)', 'receiptcode', 'F', '1', 'dkl_dckcode', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5004, 100, 0, 0, '$(languagecode)', 'receiptorganization', 'F', '1', 'dck_org', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5005, 100, 0, 0, '$(languagecode)', 'storecode', 'F', '1', 'dck_dockid', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5006, 100, 0, 0, '$(languagecode)', 'linenumber', 'F', '1', 'dkl_line', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5007, 100, 0, 0, '$(languagecode)', 'partcode', 'F', '1', 'dkl_part', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5008, 100, 0, 0, '$(languagecode)', 'partdescription', 'F', '1', 'o7get_desc', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5009, 100, 0, 0, '$(languagecode)', 'partorganization', 'F', '1', 'dkl_part_org', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5010, 100, 0, 0, '$(languagecode)', 'typedescription', 'F', '1', 'Alias_1', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5011, 100, 0, 0, '$(languagecode)', 'typecode', 'F', '1', 'orl_type', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5012, 100, 0, 0, '$(languagecode)', 'receiptquantity', 'F', '1', 'dkl_countqty', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5013, 100, 0, 0, '$(languagecode)', 'bincode', 'F', '1', 'dkl_bin', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5014, 100, 0, 0, '$(languagecode)', 'lotcode', 'F', '1', 'dkl_lot', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5015, 100, 0, 0, '$(languagecode)', 'assetid', 'F', '1', 'dkl_object', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5016, 100, 0, 0, '$(languagecode)', 'assettype', 'F', '1', 'dkl_obtype', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5017, 100, 0, 0, '$(languagecode)', 'assettypedescription', 'F', '1', 'Alias_2', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5018, 100, 0, 0, '$(languagecode)', 'assetorganization', 'F', '1', 'dkl_object_org', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5019, 100, 0, 0, '$(languagecode)', 'departmentcode', 'F', '1', 'dkl_mrc', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5020, 100, 0, 0, '$(languagecode)', 'serialnumber', 'F', '1', 'dkl_serial', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5021, 100, 0, 0, '$(languagecode)', 'manufacturerlot', 'F', '1', 'dkl_manlot', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5022, 100, 0, 0, '$(languagecode)', 'expirationdate', 'F', '1', 'dkl_manlotexp', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5023, 100, 0, 0, '$(languagecode)', 'purchaseordercode', 'F', '1', 'dkl_order', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5024, 100, 0, 0, '$(languagecode)', 'purchaseorderorganization', 'F', '1', 'dkl_order_org', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5025, 100, 0, 0, '$(languagecode)', 'returnquantity', 'F', '1', 'dkl_retnqty', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5026, 100, 0, 0, '$(languagecode)', 'reasonforreturn', 'F', '1', 'dkl_rejreason', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5027, 100, 0, 0, '$(languagecode)', 'workordercode', 'F', '1', 'orl_event', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5028, 100, 0, 0, '$(languagecode)', 'activity', 'F', '1', 'orl_act', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5029, 100, 0, 0, '$(languagecode)', 'direct', 'F', '1', 'DECODE', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5030, 100, 0, 0, '$(languagecode)', 'bylot', 'F', '1', 'o7getbylotflag', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5031, 100, 0, 0, '$(languagecode)', 'uom', 'F', '1', 'par_uom', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5032, 100, 0, 0, '$(languagecode)', 'insprejquantityuom', 'F', '1', 'Alias_3', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

/* This is not used in the code, and causes problems with number formatting
insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5033, 100, 0, 0, '$(languagecode)', 'receiptuopquantity', 'F', '1', 'round', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');
*/

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5034, 100, 0, 0, '$(languagecode)', 'uop', 'F', '1', 'orl_puruom', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5035, 100, 0, 0, '$(languagecode)', 'quantityperuop', 'F', '1', 'orl_multiply', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5036, 100, 0, 0, '$(languagecode)', 'scrappedquantity', 'F', '1', 'dkl_scrapqty', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5037, 100, 0, 0, '$(languagecode)', 'repairprice', 'F', '1', 'dkl_repairprice', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5038, 100, 0, 0, '$(languagecode)', 'printquantity', 'F', '1', 'dkl_print', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5039, 100, 0, 0, '$(languagecode)', 'suppcatalogreference', 'F', '1', 'orl_ref', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5040, 100, 0, 0, '$(languagecode)', 'assignedto', 'F', '1', 'dkl_person', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5041, 100, 0, 0, '$(languagecode)', 'assignedtodescription', 'F', '1', 'Alias_4', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5042, 100, 0, 0, '$(languagecode)', 'purchaseorderline', 'F', '1', 'dkl_ordline', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5043, 100, 0, 0, '$(languagecode)', 'equipmentcode', 'F', '1', 'Alias_5', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5044, 100, 0, 0, '$(languagecode)', 'equipmentorganization', 'F', '1', 'Alias_6', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5045, 100, 0, 0, '$(languagecode)', 'relatedworkorder', 'F', '1', 'orl_relatedwo', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5046, 100, 0, 0, '$(languagecode)', 'receiptlinestatusdisplay', 'F', '1', 'Alias_7', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5047, 100, 0, 0, '$(languagecode)', 'receiptlinestatus', 'F', '1', 'dkl_linestatus', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5048, 100, 0, 0, '$(languagecode)', 'inspectionstatuscode', 'F', '1', 'dkl_inspstatus', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5049, 100, 0, 0, '$(languagecode)', 'inspectionstatusdisplay', 'F', '1', 'Alias_8', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5050, 100, 0, 0, '$(languagecode)', 'inspectionrejectedquantity', 'F', '1', 'dkl_insprejqty', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5051, 100, 0, 0, '$(languagecode)', 'location', 'F', '1', 'dkl_location', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5052, 100, 0, 0, '$(languagecode)', 'linerstatus', 'F', '1', 'dkl_linerstatus', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5053, 100, 0, 0, '$(languagecode)', 'manufacturer', 'F', '1', 'DKL_MANUFACTURER', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5054, 100, 0, 0, '$(languagecode)', 'manufactpart', 'F', '1', 'DKL_MANUFACTPART', NULL, NULL, NULL, NULL, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5055, 100, 0, 0, '$(languagecode)', 'requestedqty', 'F', '1', 'requestedqty', NULL, NULL, NULL, NULL, '10000', '-', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5056, 100, 0, 0, '$(languagecode)', 'inspectedqty', 'F', '1', 'inspectedqty', NULL, NULL, NULL, NULL, '10000', '-', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5057, 100, 0, 0, '$(languagecode)', 'inspdate', 'F', '1', 'inspdate', NULL, NULL, NULL, NULL, '10000', '-', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5058, 100, 0, 0, '$(languagecode)', 'inspectionrequired', 'F', '1', 'inspectionrequired', NULL, NULL, NULL, NULL, '10000', '-', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5059, 100, 0, 0, '$(languagecode)', 'receivedquantity', 'F', '1', 'receivedquantity', NULL, NULL, NULL, NULL, '10000', '-', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5060, 100, 0, 0, '$(languagecode)', 'recordid', 'F', '1', 'recordid', NULL, NULL, NULL, NULL, '10000', '-', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5061, 100, 0, 0, '$(languagecode)', 'orderreceivedqty', 'F', '1', 'orderreceivedqty', NULL, NULL, NULL, NULL, '10000', '-', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values ('SSRECV', 5062, 100, 0, 0, '$(languagecode)', 'inspector', 'F', '1', 'inspector', NULL, NULL, NULL, NULL, '10000', '-', NULL, '-');

-- etc.

-------------------------------------------------------------------------------
-- Insert r5ddfield
-------------------------------------------------------------------------------

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = str(@v_field_id);
SET @v_grid_key_fields = str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.dkl_dckcode', 'VARCHAR', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5003, 'TEXT', NULL, 'receiptcode', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 1, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
SET @v_grid_key_fields = @v_grid_key_fields + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'r.dck_org', 'VARCHAR', NULL, NULL, NULL, 'LVSORGALL;gridtagname=organization');
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5004, 'TEXT', NULL, 'receiptorganization', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 2, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
SET @v_grid_key_fields = @v_grid_key_fields + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'r.dck_dockid', 'VARCHAR', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5005, 'TEXT', NULL, 'storecode', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 3, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
SET @v_grid_key_fields = @v_grid_key_fields + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.dkl_line', 'NUMBER', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5006, 'TEXT', NULL, 'linenumber', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 4, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.dkl_part', 'VARCHAR', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5007, 'TEXT', NULL, 'partcode', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 5, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'dbo.R5O7_O7GET_DESC(:parameter.language,''PART'', dkl_part + ''#'' + dkl_part_org,'''', '''')', 'MIXVARCHAR', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5008, 'TEXT', NULL, 'partdescription', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 6, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.dkl_part_org', 'VARCHAR', NULL, NULL, NULL, 'LVORGALL;gridtagname=organization');
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5009, 'TEXT', NULL, 'partorganization', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 7, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'dbo.R5O7_O7GET_DESC(:parameter.language,''UCOD'', o.orl_type,''PLTP'', '''')', 'MIXVARCHAR', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5010, 'TEXT', NULL, 'typedescription', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 8, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'o.orl_type', 'VARCHAR', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5011, 'TEXT', NULL, 'typecode', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 9, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.dkl_countqty', 'DECIMAL', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5012, 'TEXT', NULL, 'receiptquantity', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 10, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.dkl_bin', 'VARCHAR', NULL, NULL, NULL, 'LVBINALL;gridtagname=CODE');
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5013, 'TEXT', NULL, 'bincode', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 11, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.dkl_lot', 'VARCHAR', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5014, 'TEXT', NULL, 'lotcode', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 12, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.dkl_object', 'VARCHAR', NULL, NULL, NULL, 'LVASSETALL;gridtagname=assetid');
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5015, 'TEXT', NULL, 'assetid', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 13, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.dkl_obtype', 'VARCHAR', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5016, 'TEXT', NULL, 'assettype', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 14, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'dbo.R5O7_O7GET_DESC(:parameter.language,''UCOD'', d.dkl_obtype,''OBTP'', '''')', 'MIXVARCHAR', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5017, 'TEXT', NULL, 'assettypedescription', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 15, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.dkl_object_org', 'VARCHAR', NULL, NULL, NULL, 'LVORGALL;gridtagname=organization');
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5018, 'TEXT', NULL, 'assetorganization', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 16, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.dkl_mrc', 'VARCHAR', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5019, 'TEXT', NULL, 'departmentcode', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 17, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.dkl_serial', 'MIXVARCHAR', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5020, 'TEXT', NULL, 'serialnumber', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 18, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.dkl_manlot', 'MIXVARCHAR', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5021, 'TEXT', NULL, 'manufacturerlot', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 19, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.dkl_manlotexp', 'DATE', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5022, 'TEXT', NULL, 'expirationdate', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 20, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.dkl_order', 'VARCHAR', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5023, 'TEXT', NULL, 'purchaseordercode', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 21, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.dkl_order_org', 'VARCHAR', NULL, NULL, NULL, 'LVSORGALL;gridtagname=organization');
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5024, 'TEXT', NULL, 'purchaseorderorganization', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 22, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.dkl_retnqty', 'DECIMAL', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5025, 'TEXT', NULL, 'returnquantity', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 23, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.dkl_rejreason', 'VARCHAR', NULL, NULL, NULL, 'LVRETURNREASON;gridtagname=reasonforreturn');
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5026, 'TEXT', NULL, 'reasonforreturn', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 24, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'o.orl_event', 'VARCHAR', NULL, NULL, NULL, 'LVWORK;gridtagname=workorder');
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5027, 'TEXT', NULL, 'workordercode', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 25, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'o.orl_act', 'NUMBER', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5028, 'TEXT', NULL, 'activity', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 26, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'case d.dkl_direct when ''E'' then ''+'' when ''S'' then ''-'' else ''-'' end', 'CHKBOOLEAN', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5029, 'CHECKBOX', NULL, 'direct', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 27, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'dbo.o7getbylotflag( d.dkl_part, d.dkl_part_org)', 'CHKBOOLEAN', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5030, 'CHECKBOX', NULL, 'bylot', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 28, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'p.par_uom', 'MIXVARCHAR', NULL, NULL, NULL, 'LVUOMS;gridtagname=UOMCODE');
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5031, 'TEXT', NULL, 'uom', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 29, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'p.par_uom', 'MIXVARCHAR', NULL, NULL, NULL, 'LVUOMS;gridtagname=UOMCODE');
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5032, 'TEXT', NULL, 'insprejquantityuom', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 30, 0, 'LIST');

/* This is not used in the code and causes problems in the integration with number formatting
EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'round(d.dkl_countqty / isnull(o.orl_multiply,1), 3)', 'DECIMAL', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5033, 'TEXT', NULL, 'receiptuopquantity', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 31, 0, 'LIST');
*/

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'o.orl_puruom', 'MIXVARCHAR', NULL, NULL, NULL, 'LVUOMS;gridtagname=UOMCODE');
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5034, 'TEXT', NULL, 'uop', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 32, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'o.orl_multiply', 'DECIMAL', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5035, 'TEXT', NULL, 'quantityperuop', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 33, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.dkl_scrapqty', 'DECIMAL', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5036, 'TEXT', NULL, 'scrappedquantity', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 34, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.dkl_repairprice', 'CURRENCY', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5037, 'TEXT', NULL, 'repairprice', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 35, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.dkl_print', 'NUMBER', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5038, 'TEXT', NULL, 'printquantity', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 36, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'orl_ref', 'MIXVARCHAR', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5039, 'TEXT', NULL, 'suppcatalogreference', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 37, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.dkl_person', 'VARCHAR', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5040, 'TEXT', NULL, 'assignedto', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 38, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'dbo.R5O7_O7GET_DESC(:parameter.language,''PERS'', d.dkl_person,'''', '''')', 'MIXVARCHAR', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5041, 'TEXT', NULL, 'assignedtodescription', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 39, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.dkl_ordline', 'NUMBER', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5042, 'TEXT', NULL, 'purchaseorderline', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 40, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'CASE e.evt_multiequip WHEN ''+'' THEN
  CASE WHEN o.orl_relatedwo IS NULL THEN
    (SELECT b.bot_text FROM r5boilertexts b WHERE bot_function = ''LVMECO'' AND bot_fld1 = ''ALLEQUIPMENT'' and bot_fld2 = ''LV_CHOICES'' and bot_lang = :parameter.language )
  WHEN o.orl_relatedwo = o.orl_event THEN
    (SELECT b.bot_text FROM r5boilertexts b WHERE bot_function = ''LVMECO'' AND bot_fld1 = ''WOHEADEREQUIPMENT'' and bot_fld2 = ''LV_CHOICES'' and bot_lang = :parameter.language )
  ELSE
    (SELECT evt_object FROM r5events WHERE evt_code = o.orl_relatedwo)
  END
ELSE
  e.evt_object
END', 'MIXVARCHAR', NULL, NULL, NULL, 'LVWOEQUIPALL;gridtagname=equipment');
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5043, 'TEXT', NULL, 'equipmentcode', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 41, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'CASE e.evt_multiequip WHEN ''+'' THEN
  CASE WHEN o.orl_relatedwo IS NULL THEN
    null
  WHEN o.orl_relatedwo = o.orl_event THEN
    null
  ELSE
    (SELECT evt_object_org FROM r5events WHERE evt_code = o.orl_relatedwo)
  END
ELSE
  e.evt_object_org
END', 'VARCHAR', NULL, NULL, NULL, 'LVORGALL;gridtagname=organization');
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5044, 'TEXT', NULL, 'equipmentorganization', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 42, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'o.orl_relatedwo', 'VARCHAR', NULL, NULL, NULL, 'LVEVNTALLMEC;gridtagname=workorder');
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5045, 'TEXT', NULL, 'relatedworkorder', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 43, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'dbo.R5O7_O7GET_DESC(:parameter.language,''UCOD'', d.dkl_linestatus,''DLST'', '''')', 'MIXVARCHAR', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5046, 'TEXT', NULL, 'receiptlinestatusdisplay', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 44, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.dkl_linestatus', 'VARCHAR', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5047, 'TEXT', NULL, 'receiptlinestatus', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 45, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.dkl_inspstatus', 'VARCHAR', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5048, 'TEXT', NULL, 'inspectionstatuscode', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 46, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'dbo.R5O7_O7GET_DESC(:parameter.language,''UCOD'', d.dkl_inspstatus,''IPST'', '''')', 'MIXVARCHAR', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5049, 'TEXT', NULL, 'inspectionstatusdisplay', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 47, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.dkl_insprejqty', 'DECIMAL', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5050, 'TEXT', NULL, 'inspectionrejectedquantity', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 48, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.dkl_location', 'MIXVARCHAR', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5051, 'TEXT', NULL, 'location', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 49, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.dkl_linerstatus', 'VARCHAR', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5052, 'TEXT', NULL, 'linerstatus', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 50, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'DKL_MANUFACTURER', 'VARCHAR', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5053, 'TEXT', NULL, 'manufacturer', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 51, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'DKL_MANUFACTPART', 'MIXVARCHAR', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5054, 'TEXT', NULL, 'manufactpart', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 52, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'o.ORL_ORDQTY', 'DECIMAL', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5055, 'TEXT', NULL, 'requestedqty', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 53, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.dkl_inspectedqty', 'DECIMAL', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5056, 'TEXT', NULL, 'inspectedqty', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 54, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.dkl_inspdate', 'DATE', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5057, 'TEXT', NULL, 'inspdate', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 55, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.dkl_inspect', 'CHKBOOLEAN', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5058, 'CHECKBOX', NULL, 'inspectionrequired', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 56, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.dkl_recvqty', 'DECIMAL', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5059, 'TEXT', NULL, 'receivedquantity', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 57, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.DKL_UPDATECOUNT', 'NUMBER', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5060, 'TEXT', NULL, 'recordid', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 58, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'o.ORL_RECVQTY', 'DECIMAL', NULL, NULL, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5061, 'TEXT', NULL, 'orderreceivedqty', NULL, NULL, 'n', 1, NULL, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 59, 0, 'LIST');

EXECUTE [dbo].[R5O7_O7MAXSEQ] @v_field_id OUTPUT, 'DDF', '1', @sChk OUTPUT;
SET @v_field_id_list = @v_field_id_list + ',' + str(@v_field_id);
PRINT 'Field Id: ' + str(@v_field_id)

insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (@v_field_id, 'd.dkl_inspector', 'VARCHAR', NULL, null, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (@v_field_id, @v_grid_id, 'SSRECV', 5062, 'TEXT', NULL, 'inspector', NULL, NULL, 'n', 1, null, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (@v_dataspy_id, @v_field_id, '180', 60, 0, 'LIST');


-- etc.


-------------------------------------------------------------------------------
-- Setup field keys on r5grid
-------------------------------------------------------------------------------

update r5grid set 
grd_keyfields = @v_grid_key_fields, 
grd_filterablelist = @v_field_id_list,
grd_sortablelist = @v_field_id_list,
grd_displayablelist = @v_field_id_list
where grd_gridid=@v_grid_id;


--ROLLBACK TRAN T1
COMMIT TRAN T1