declare

v_grid_name varchar(6);
v_grid_desc varchar(30);
v_grid_id numeric(14, 0);
v_field_id numeric(14, 0);
v_field_id_list VARCHAR(1000);
v_grid_key_fields VARCHAR(200);
v_dataspy_id numeric(14, 0);
v_language VARCHAR2(2);

r5boilertexts_exists numeric(1);
r5grid_exists numeric(1);
r5functions_exists numeric(1);
sequence_check varchar2(3);

begin

v_grid_name := 'WUDSPY';
v_grid_desc := 'Advanced Mobile DataSpyIDs';
v_language := '&1';

-------------------------------------------------------------------------------
-- Cleanup existing r5boilertexts
-------------------------------------------------------------------------------

select count(*) into r5boilertexts_exists
from r5boilertexts
where BOT_FUNCTION = v_grid_name
and rownum = 1;

IF r5boilertexts_exists = 1 THEN
  DELETE FROM r5boilertexts where BOT_FUNCTION = v_grid_name;
END IF;

-------------------------------------------------------------------------------
-- Cleanup existing r5grid and related data
-------------------------------------------------------------------------------

select count(*) into r5grid_exists
from r5grid
where GRD_GRIDNAME = v_grid_name
and rownum = 1;

IF r5grid_exists = 1 THEN
    DELETE FROM r5queryfield where DQF_DDSPYID in
    (
        select DDS_DDSPYID from R5dddataspy where DDS_GRIDID in
        (
            select grd_gridid from r5grid where GRD_GRIDNAME = v_grid_name
        )
    );
    DELETE FROM r5usegridsysdefault where usd_dataspyid in
    (
        select DDS_DDSPYID from R5dddataspy where DDS_GRIDID in
        (
            select grd_gridid from r5grid where GRD_GRIDNAME = v_grid_name
        )
    );
    DELETE FROM R5dddataspy WHERE DDS_GRIDID in
    (
        select grd_gridid from r5grid where GRD_GRIDNAME = v_grid_name
    );
    DELETE FROM r5gridfield where GFD_GRIDID in
    (
        select grd_gridid from r5grid where GRD_GRIDNAME = v_grid_name
    );
    DELETE FROM r5grid WHERE GRD_GRIDNAME = v_grid_name;
END IF;

-------------------------------------------------------------------------------
-- Cleanup existing r5functions and related data
-------------------------------------------------------------------------------

select count(*) into r5functions_exists
from r5functions
where FUN_CODE = v_grid_name
and rownum = 1;

IF r5functions_exists = 1 THEN
  DELETE FROM r5functions where FUN_CODE = v_grid_name;
END IF;

-------------------------------------------------------------------------------
-- Insert r5functions
-------------------------------------------------------------------------------

insert into r5functions
(
    FUN_CODE,
    FUN_DESC,
    FUN_CLASS,
    FUN_SUBTYPE,
    FUN_FILE,
    FUN_PUBLIC,
    FUN_SELECT,
    FUN_BACKGROUND,
    FUN_DIRSEL,
    FUN_SYSTEM,
    FUN_DISPLAYAP,
    FUN_DISPLAYFT,
    FUN_POPUPAP,
    FUN_POPUPFT,
    FUN_DESCCHANGED,
    FUN_CLASS_ORG,
    FUN_LST,
    FUN_RS,
    FUN_HDR,
    FUN_EWSREPORT,
    FUN_PRDDATASRC,
    FUN_EWSURLNEW,
    FUN_REPDISABLED,
    FUN_MEKEY
)
values
(
    v_grid_name,
    v_grid_desc,
    'WEBD',
    'M',
    'R5MENU',
    '-',
    '?',
    '-',
    '-',
    '+',
    '-',
    '+',
    '-',
    '-',
    '-',
    '*',
    '+',
    '-',
    '-',
    '-',
    '-',
    '-',
    '-',
    'YN'
);

-------------------------------------------------------------------------------
-- Insert r5grid
-------------------------------------------------------------------------------

--select MAX(grd_gridid)+1 into v_grid_id from r5grid;
r5o7.o7maxseq(v_grid_id, 'GRD', '1', sequence_check);

insert into r5grid
(
    GRD_GRIDID,
    GRD_DESC,
    GRD_BASEQUERY,
    GRD_GRIDNAME,
    GRD_BOTFUNCTION,
    GRD_PORTLETFLAG,
    GRD_SECENTITY,
    GRD_HINTS,
    GRD_TAB,
    GRD_GRIDTYPE,
    GRD_UNITS,
    GRD_OPTIMIZERON,
    GRD_DISTINCT,
    GRD_COMMITFLAG,
    GRD_CUSTOMFIELDCODE,
    GRD_NOSCREENDESIGNER
)
values
(
    v_grid_id,
    v_grid_desc,
    'from r5grid g, r5dddataspy ds
     where g.grd_gridid = ds.dds_gridid
     and ds.dds_ddspyname like ''%AM''
     order by g.grd_gridname ',
    v_grid_name,
    v_grid_name,
    '-',
    NULL,
    NULL,
    '+',
    2,
    NULL,
    '-',
    '-',
    NULL,
    NULL,
    '-'
);

-------------------------------------------------------------------------------
-- Insert r5dddataspy
-------------------------------------------------------------------------------

--select MAX(dds_ddspyid)+1 into v_dataspy_id from r5dddataspy;
r5o7.o7maxseq(v_dataspy_id, 'DDS', '1', sequence_check);

insert into R5dddataspy
(
    DDS_DDSPYNAME,
    DDS_DDSPYID,
    DDS_AUTORUN,
    DDS_SCOPE,
    DDS_ORGANIZATION,
    DDS_UPDATESTAMP,
    DDS_UPDATEBYUSER,
    DDS_CREATEDSTAMP,
    DDS_UPDATEABLE,
    DDS_FILTERSTRXML,
    DDS_SORTSTRXML,
    DDS_FIELDLIST,
    DDS_DISPLAYROW,
    DDS_OWNER,
    DDS_GRIDID,
    DDS_TYPE,
    DDS_DEFAULTFLAG,
    DDS_FIELDLIST_PORTLET,
    DDS_CLIENTROWS,
    DDS_PORTLETROWS,
    DDS_HINTS,
    DDS_BOTNAME,
    DDS_USERFILTER,
    DDS_SECURITYDATASPY,
    DDS_MEKEY
)
values
(
    v_grid_desc,
    v_dataspy_id,
    NULL,
    '-',
    '*',
    null,
    NULL,
    sysdate,
    NULL,
    '<FILTERABLE />',
    '<SORTABLE />',
    NULL,
    null,
    'R5',
    v_grid_id,
    'SD',
    '+',
    NULL,
    30,
    null,
    NULL,
    'DSNAME',
    NULL,
    '-',
    'YY'
);

-------------------------------------------------------------------------------
-- Insert r5boilertexts
-------------------------------------------------------------------------------

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values (v_grid_name, 1, 100, 0, 0, v_language, 'List View', 'TB', '1', 'LST', NULL, NULL, null, null, '10000', NULL, NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values (v_grid_name, 2, 100, 0, 0, v_language, v_grid_desc, 'F', '1', 'UDG_HDRLABEL', NULL, NULL, null, null, '10000', '+', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values (v_grid_name, 3, 100, 0, 0, v_language, 'All Records', 'F', '1', 'DSNAME', NULL, NULL, null, null, '10000', NULL, NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values (v_grid_name, 4, 100, 0, 0, v_language, 'grd_gridid', 'F', '1', 'grd_gridid', NULL, NULL, null, null, '10000', '-', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values (v_grid_name, 5, 100, 0, 0, v_language, 'grd_gridname', 'F', '1', 'grd_gridname', NULL, NULL, null, null, '10000', '-', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values (v_grid_name, 6, 100, 0, 0, v_language, 'dds_ddspyid', 'F', '1', 'dds_ddspyid', NULL, NULL, null, null, '10000', '-', NULL, '-');

insert into r5boilertexts (BOT_FUNCTION, BOT_NUMBER, BOT_LENGTH, BOT_XPOS, BOT_YPOS, BOT_LANG, BOT_TEXT, BOT_DEST, BOT_PAGE, BOT_FLD1, BOT_FLD2, BOT_PRTP, BOT_LVCR, BOT_ADLEN, BOT_POOL, BOT_CHANGED, BOT_DISPLAY, BOT_CLONED)
values (v_grid_name, 7, 100, 0, 0, v_language, 'dds_ddspyname', 'F', '1', 'dds_ddspyname', NULL, NULL, null, null, '10000', '-', NULL, '-');

-------------------------------------------------------------------------------
-- Insert r5ddfield, r5gridfield, r5queryfield
-------------------------------------------------------------------------------

--select max(DDF_FIELDID) + 1 into v_field_id from r5ddfield;
r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id;
v_grid_key_fields := v_field_id;
insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (v_field_id, 'grd_gridid', 'VARCHAR', NULL, null, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (v_field_id, v_grid_id, v_grid_name, 4, 'TEXT', NULL, 'grd_gridid', NULL, NULL, 'n', 1, null, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (v_dataspy_id, v_field_id, '180', 1, 0, 'LIST');

--select max(DDF_FIELDID) + 1 into v_field_id from r5ddfield;
r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || v_field_id;
insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (v_field_id, 'grd_gridname', 'VARCHAR', NULL, null, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (v_field_id, v_grid_id, v_grid_name, 5, 'TEXT', NULL, 'grd_gridname', NULL, NULL, 'n', 1, null, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (v_dataspy_id, v_field_id, '180', 2, 0, 'LIST');

--select max(DDF_FIELDID) + 1 into v_field_id from r5ddfield;
r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || v_field_id;
v_grid_key_fields := v_grid_key_fields || ',' || v_field_id;
insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (v_field_id, 'dds_ddspyid', 'NUMBER', NULL, null, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (v_field_id, v_grid_id, v_grid_name, 6, 'TEXT', NULL, 'dds_ddspyid', NULL, NULL, 'n', 1, null, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (v_dataspy_id, v_field_id, '180', 3, 0, 'LIST');

--select max(DDF_FIELDID) + 1 into v_field_id from r5ddfield;
r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || v_field_id;
insert into r5ddfield (DDF_FIELDID, DDF_SOURCENAME, DDF_DATATYPE, DDF_DESC, DDF_VALUEMAPID, DDF_RENTITY, DDF_LVGRID)
values (v_field_id, 'dds_ddspyname', 'VARCHAR', NULL, null, NULL, NULL);
insert into r5gridfield (GFD_FIELDID, GFD_GRIDID, GFD_BOTFUNCTION, GFD_BOTNUMBER, GFD_CONTROLTYPE, GFD_SCRIPTEVENT, GFD_TAGNAME, GFD_TAGPARAMS, GFD_AGGFUNC, GFD_FIELDTYPE, GFD_OCCURRENCE, GFD_DEPENDENT, GFD_SECENTITY)
values (v_field_id, v_grid_id, v_grid_name, 7, 'TEXT', NULL, 'dds_ddspyname', NULL, NULL, 'n', 1, null, NULL);
insert into r5queryfield (DQF_DDSPYID, DQF_FIELDID, DQF_COLUMNWIDTH, DQF_COLUMNORDER, DQF_UPDATECOUNT, DQF_VIEWTYPE)
values (v_dataspy_id, v_field_id, '180', 4, 0, 'LIST');


-------------------------------------------------------------------------------
-- Update references on r5grid
-------------------------------------------------------------------------------

Update r5grid set 
    grd_keyfields = v_grid_key_fields, 
    grd_filterablelist = v_field_id_list,
    grd_sortablelist = v_field_id_list,
    grd_displayablelist = v_field_id_list
where grd_gridid = v_grid_id;

commit;

end;

/